@@ -31,16 +31,17 @@ import java.util.List;
 import java.util.Optional;
 import java.util.Properties;
 
+
 class VersionProps {
 
     private static final String launcher_name =
         "openjdk";
 
     private static final String java_version =
-        "11.0.6";
+        "11.0.8";
 
     private static final String java_version_date =
-        "2020-01-14";
+        "2020-07-14";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -48,22 +49,28 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.6+9-jvmci-19.3-b07";
+        "11.0.8+10-jvmci-20.2-b03";
 
     private static final String VERSION_NUMBER =
-        "11.0.6";
+        "11.0.8";
 
     private static final String VERSION_BUILD =
-        "9";
+        "10";
 
     private static final String VERSION_PRE =
         "";
 
     private static final String VERSION_OPT =
-        "jvmci-19.3-b07";
+        "jvmci-20.2-b03";
 
     private static final boolean isLTS =
-        "jvmci-19.3-b07".startsWith("LTS");
+        "jvmci-20.2-b03".startsWith("LTS");
+
+    private static final String VENDOR =
+        "GraalVM Community";
+
+    private static final String VENDOR_URL =
+        "https://www.graalvm.org/";
 
     // The remaining fields must not be final,
     // so that they can be redefined by jlink plugins
@@ -73,11 +80,11 @@ class VersionProps {
         "";
 
     private static String VENDOR_URL_BUG =
-        "https://bugreport.java.com/bugreport/";
+        "https://github.com/oracle/graal/issues";
 
     // This field is read by HotSpot
     private static String VENDOR_URL_VM_BUG =
-        "https://bugreport.java.com/bugreport/crash.jsp";
+        "https://github.com/oracle/graal/issues";
 
     public static void init(Properties props) {
         props.put("java.version", java_version);
@@ -86,6 +93,9 @@ class VersionProps {
         props.put("java.runtime.name", java_runtime_name);
         if (!VENDOR_VERSION.isEmpty())
             props.put("java.vendor.version", VENDOR_VERSION);
+
+        props.put("java.vendor", VENDOR);
+        props.put("java.vendor.url", VENDOR_URL);
         props.put("java.vendor.url.bug", VENDOR_URL_BUG);
     }
 
